---
name: "\U0001F680 Feature request"
about: Suggest an idea for this project
labels: enhancement, triage

---

<!--
**** DELETE THIS BLOCK ****

Thanks for filing an issue!  Please keep keep issues limited to bug reports,
feature requests, and other general issues. For support questions, please feel
free to reach out on stackoverflow:
https://stackoverflow.com/questions/tagged/cheroot+or+cherrypy

**** /DELETE THIS BLOCK ****
-->

❓ **I'm submitting a ...**
- [ ] 🐞 bug report
- [X] 🐣 feature request
- [ ] ❓ question about the decisions made in the repository

🐞 **Is your feature request related to a problem? Please describe.**
<!--
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]
-->


🐣 **Describe the solution you'd like**
<!--
A clear and concise description of what you want to happen.
-->


📋 **Describe alternatives you've considered**
<!--
A clear and concise description of any alternative solutions or features you've considered.
-->


📋 **Additional context**
<!--
Add any other context or screenshots about the feature request here.
(e.g. detailed explanation, related issues, links for us to have context, e.g. stackoverflow, gitter, etc.)
-->
